@@ -29,7 +29,9 @@
 #' @param factor.groups If not \code{NULL}, \code{df} will be splitted into sub-groups,
 #'          where the item analysis is carried out for each of these groups. Must be a vector of same
 #'          length as \code{ncol(df)}, where each item in this vector represents the group number of
-#'          the related columns of \code{df}. See 'Examples'.
+#'          the related columns of \code{df}. If \code{factor.groups = "auto"}, a principal
+#'          component analysis with Varimax rotation is performed, and the resulting
+#'          groups for the components are used as group index. See 'Examples'.
 #' @param factor.groups.titles Titles for each factor group that will be used as table caption for each
 #'          component-table. Must be a character vector of same length as \code{length(unique(factor.groups))}.
 #'          Default is \code{"auto"}, which means that each table has a standard caption \emph{Component x}.
@@ -112,14 +114,18 @@
 #'
 #' # Compute PCA on Cope-Index, and perform a
 #' # item analysis for each extracted factor.
-#' factor.groups <- sjt.pca(mydf)$factor.index
-#' sjt.itemanalysis(mydf, factor.groups)}
+#' indices <- sjt.pca(mydf)$factor.index
+#' sjt.itemanalysis(mydf, factor.groups = indices)
+#'
+#' # or, equivalent
+#' sjt.itemanalysis(mydf, factor.groups = "auto")}
 #'
 #' @importFrom psych describe
 #' @importFrom stats shapiro.test na.omit
 #' @importFrom sjstats mean_n
-#' @importFrom performance item_reliability cronbachs_alpha item_intercor
+#' @importFrom performance item_reliability cronbachs_alpha item_intercor principal_components
 #' @importFrom sjmisc std
+#' @importFrom sjlabelled set_label
 #' @export
 sjt.itemanalysis <- function(df,
                              factor.groups = NULL,
@@ -139,13 +145,31 @@ sjt.itemanalysis <- function(df,
   # check encoding
   encoding <- get.encoding(encoding, df)
 
+  # convert ordered factors to numeric
+  ordered_vars <- sapply(df, is.ordered)
+  if (any(ordered_vars)) df[ordered_vars] <- sjlabelled::as_numeric(df[ordered_vars])
+
+  # Warn if factors are used
+  factor_vars <- sapply(df, is.factor)
+  if (any(factor_vars)) {
+    df[factor_vars] <- sjlabelled::as_numeric(df[factor_vars])
+    warning("At least one variable is of type factor, please check if the factor levels are ordered correctly.")
+  }
+
   # auto-detect variable labels
   varlabels <- sjlabelled::get_label(df, def.value = colnames(df))
   colnames(df) <- varlabels
 
   # check whether we have (factor) groups
   # for data frame
-  if (is.null(factor.groups)) factor.groups <- rep(1, length.out = ncol(df))
+  if (is.null(factor.groups))
+    factor.groups <- rep(1, length.out = ncol(df))
+  else if (inherits(factor.groups, "perf_pca_rotate"))
+    factor.groups <- apply(factor.groups, 1, function(i) which.max(abs(i)))
+  else if (length(factor.groups) == 1 && factor.groups == "auto") {
+    pr <- performance::principal_components(df, rotation = "varimax")
+    factor.groups <- apply(pr, 1, function(i) which.max(abs(i)))
+  }
 
   # data frame with data from item-analysis-output-table
   df.ia <- list()
@@ -337,5 +361,9 @@ sjt.itemanalysis <- function(df,
   html$cronbach.values <- cronbach.total
   html$ideal.item.diff <- diff.ideal.list
 
+  sjlabelled::set_label(html$index.scores) <- purrr::map2_chr(mic.total, cronbach.total, ~ sprintf(
+    "Mean icc=%.3f; Cronbach's Alpha=%.3f", .x, .y
+  ))
+
   html
 }
