@@ -48,7 +48,6 @@
 #'          to label variable values in the output.
 #'
 #' @inheritParams tab_model
-#' @inheritParams sjp.glmer
 #' @inheritParams sjp.grpfrq
 #'
 #' @return Invisibly returns
@@ -116,6 +115,7 @@ sjt.xtab <- function(var.row,
                      show.legend = FALSE,
                      show.na = FALSE,
                      show.summary = TRUE,
+                     drop.empty = TRUE,
                      statistics = c("auto", "cramer", "phi", "spearman", "kendall", "pearson", "fisher"),
                      string.total = "Total",
                      digits = 1,
@@ -154,6 +154,13 @@ sjt.xtab <- function(var.row,
   # --------------------------------------------------------
   var.name.row <- get_var_name(deparse(substitute(var.row)))
   var.name.col <- get_var_name(deparse(substitute(var.col)))
+
+  # remove empty value-labels
+  if (drop.empty) {
+    var.row <- sjlabelled::drop_labels(var.row)
+    var.col <- sjlabelled::drop_labels(var.col)
+  }
+
   # --------------------------------------------------------
   # create cross table of frequencies and percentages
   # --------------------------------------------------------
