@@ -258,19 +258,14 @@ get_title_part <- function(x, grps, level, i) {
 
 
 #' @importFrom rlang .data
-#' @importFrom dplyr select filter group_vars
+#' @importFrom dplyr select filter group_modify group_vars
 #' @importFrom stats complete.cases
 #'
 get_grouped_data <- function(x) {
-  # nest data frame
-  grps <- tidyr::nest(x)
-
-  # remove NA category
-  cc <- grps %>%
-    dplyr::select(-.data$data) %>%
-    stats::complete.cases()
-  # select only complete cases
-  grps <- grps %>% dplyr::filter(!! cc)
+  # retain observations that are complete wrt grouping vars, then nest
+  grps <- x %>%
+    dplyr::group_modify(~ dplyr::filter(.x, stats::complete.cases(.y))) %>%
+    tidyr::nest()
 
   # arrange data
   if (length(dplyr::group_vars(x)) == 1)
