@@ -275,7 +275,9 @@ sjplot_colors <- list(
   `eight` = c("#003f5c", "#2f4b7c", "#665191", "#a05195", "#d45087", "#f95d6a", "#ff7c43", "#ffa600"),
   `circus` = c("#0664C9", "#C1241E", "#EBD90A", "#6F130D", "#111A79"),
   `system` = c("#0F2838", "#F96207", "#0DB0F3", "#04EC04", "#FCC44C"),
-  `hero` = c("#D2292B", "#165E88", "#E0BD1C", "#D57028", "#A5CB39", "#8D8F70")
+  `hero` = c("#D2292B", "#165E88", "#E0BD1C", "#D57028", "#A5CB39", "#8D8F70"),
+  `flat` = c("#2980b9", "#c0392b", "#16a085", "#f39c12", "#8e44ad", "#7f8c8d", "#d35400"),
+  `social` = c("#0077B5", "#b92b27", "#00b489", "#f57d00", "#410093", "#21759b", "#ff3300")
 )
 
 
