@@ -49,6 +49,8 @@ get_tidy_data <- function(model, ci.lvl, tf, type, bpe, facets, show.zeroinf, p.
     tidy_gmnl_model(model, ci.lvl)
   else if (inherits(model, "multinom"))
     tidy_multinom_model(model, ci.lvl, facets)
+  else if (inherits(model, "gamlss"))
+    tidy_gamlss_model(model, ci.lvl)
   else if (inherits(model, "gam"))
     tidy_gam_model(model, ci.lvl)
   else if (inherits(model, "Zelig-relogit"))
@@ -107,9 +109,9 @@ tidy_generic <- function(model, ci.lvl, facets, p.val) {
         dat$p.value <- NA
       } else {
         dat$p.value <- pv$p.value
-        dat$std.error <- attr(pv, "se.kr", exact = TRUE)
-        dat$statistic <- attr(pv, "t.kr", exact = TRUE)
-        dat$df <- round(attr(pv, "df.kr", exact = TRUE))
+        if (!is.null(attr(pv, "se.kr", exact = TRUE))) dat$std.error <- attr(pv, "se.kr", exact = TRUE)
+        if (!is.null(attr(pv, "t.kr", exact = TRUE))) dat$statistic <- attr(pv, "t.kr", exact = TRUE)
+        if (!is.null(attr(pv, "df.kr", exact = TRUE))) dat$df <- round(attr(pv, "df.kr", exact = TRUE))
       }
 
     } else {
@@ -883,6 +885,32 @@ tidy_gam_model <- function(model, ci.lvl) {
 }
 
 
+#' @importFrom insight get_parameters
+tidy_gamlss_model <- function(model, ci.lvl) {
+
+  # compute ci, two-ways
+  ci <- get_confint(ci.lvl)
+
+  # get estimates
+
+  sm <- summary(model)
+  pars <- insight::get_parameters(model)
+
+  est <- pars$estimate[pars$component == "conditional"]
+  se <- sm[1:length(est), 2]
+
+  data_frame(
+    term = pars$parameter[pars$component == "conditional"],
+    estimate = est,
+    std.error = se,
+    statistic = sm[1:length(est), 3],
+    conf.low = est - stats::qnorm(ci) * se,
+    conf.high = est + stats::qnorm(ci) * se,
+    p.value = sm[1:length(est), 4]
+  )
+}
+
+
 #' @importFrom rlang .data
 #' @importFrom stats coef qnorm
 tidy_zelig_model <- function(model, ci.lvl) {
